import { Address } from './address.type';
import { Entity, Column, OneToMany, OneToOne, JoinColumn, ManyToMany, JoinTable, ManyToOne } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsString, IsNumber, IsNotEmpty, IsOptional, IsArray, IsBoolean } from 'class-validator';
import { PermissionCons } from './permission.type';

@Entity()
export class User extends BasicREntity {

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  name: string;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  emails: string;

  @IsString()
  @IsOptional()
  @Column({ nullable: true })
  linkPhoto?: string;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  phones: string;

  @IsString()
  @IsNotEmpty()
  @Column({ nullable: false })
  identification: String;

  @JoinColumn()
  @IsNotEmpty()
  @OneToOne(type => Address, { cascade: true, nullable: false })
  address?: Address;

  @IsBoolean()
  @IsOptional()
  @Column({ nullable: false, default: false })
  relog: boolean;

  @IsBoolean()
  @IsOptional()
  @Column({ nullable: false, default: true })
  tutorial: boolean;

  @IsString()
  @IsOptional()
  @Column({ nullable: false })
  password: string;

  @IsOptional()
  @ManyToMany(type => PermissionCons, permission => permission.users, { nullable: true })
  @JoinTable({ name: 'user_permission' })
  permissions?: PermissionCons[];
}