import { IsString, IsDefined, IsOptional, IsArray, IsBoolean } from 'class-validator';
import { BasicNREntity } from '../basicNR.type';

export class Profile {
  @IsString()
  @IsOptional()
  photoLink?: string;

  @IsArray()
  @IsOptional()
  phones?: string[];

  @IsArray()
  @IsOptional()
  emails?: string[];

  photoBase64Content?: string;
}

export class Config {
  @IsBoolean()
  @IsDefined()
  timelineContent: boolean = true;

  @IsBoolean()
  @IsDefined()
  aboutPlatform: boolean = true;

  @IsBoolean()
  @IsDefined()
  documents: boolean = true;
}

export class UserLat extends BasicNREntity {
  @IsString()
  @IsDefined()
  identification: string;

  @IsBoolean()
  @IsOptional()
  tutorial?: boolean;

  @IsString()
  @IsDefined()
  voucher: string;

  @IsString()
  @IsOptional()
  password?: string;

  @IsOptional()
  profile?: Profile;

  @IsOptional()
  config?: Config;

  @IsOptional()
  permissionIds?: string[];
}
