import { IsArray, IsString, IsNotEmpty, IsOptional, IsBoolean, IsNumber } from 'class-validator';
import { BasicNREntity } from '../basicNR.type';
/* eslint-disable no-unused-vars */

export enum NotificationType {
  COLLECT = 'COLLECT',
  MAGAZINES = 'MAGAZINES',
  QUALITY = 'QUALITY',
  TEMPERATURE = 'TEMPERATURE',
  OTHER = 'OTHER'
}

export class ValueConditional {
  @IsNotEmpty()
  @IsString()
  signal: string;

  @IsNotEmpty()
  @IsNumber()
  value: number;

  @IsNotEmpty()
  @IsBoolean()
  inclusive: boolean;

  @IsOptional()
  @IsBoolean()
  partialResult?: boolean;

  @IsOptional()
  @IsBoolean()
  finalResult?: boolean;
}

export class NotificationRegister extends BasicNREntity {
  @IsNotEmpty()
  type: NotificationType;

  @IsNotEmpty()
  @IsString()
  title: string;

  @IsNotEmpty()
  @IsString()
  description: string;

  @IsOptional()
  @IsBoolean()
  alert?: boolean;

  @IsOptional()
  @IsBoolean()
  push?: boolean;

  // TEMPERATURE AND QUALITY
  @IsOptional()
  @IsArray()
  conditionals?: ValueConditional[];

  // OTHER
  @IsOptional()
  @IsArray()
  frequency?: string[]; // https://www.npmjs.com/package/human-to-cron
}
