import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToOne, OneToMany, ManyToOne } from 'typeorm';
import { BasicREntity } from '../../basicR.type';
import { IsNumber, IsDate, IsNotEmpty, IsOptional, IsString } from 'class-validator';
import { Farm } from '../../visit/farm.type'

export enum RoutineExpenseCategory {
  RENT,
  SOCIAL_EXPENSES,
  ELECTRICITY,
  EMPLOYEE,
  PHONE,
  INTERNET

// Ordem de produção - Milho Rehidratado
// Ordem de produção - Silagem de Milho (Volumoso)
// Ordem de produção - Manutenção de Pastagem (Volumoso)

}

export enum RoutineExpenseKinship{
  OWNER,
  FATHER,
  MOTHER,
  SON,
  DAUGHTER,
  UNCLE,
  NEPHEW
}

export enum RoutineExpenseRole{
  TECHNICIAN,
  MANAGER,
  HANDLER
}

@Entity()
export class RoutineExpense extends BasicREntity {
  
  @IsNotEmpty()
  @ManyToOne(type => Farm,{ nullable: false })
  farm: Farm;

  @IsNotEmpty()
  @Column()
  @IsNumber()
  value:Number;

  @IsOptional()
  @Column()
  @IsString()
  description:String;

  @IsOptional()
  @Column({type:'int'})
  @IsNumber()
  kinship:RoutineExpenseKinship;

  @IsOptional()
  @Column({type:'int'})
  @IsNumber()
  role:RoutineExpenseRole;

  @IsNotEmpty()
  @Column({type:'int'})
  @IsNumber()
  category:RoutineExpenseCategory;

  @IsOptional()
  @Column()
  @IsNumber()
  percentDedication:Number;

}