import { IsDate, IsString, IsNotEmpty, IsNumber } from 'class-validator';
import { Column, Entity, IsNull, ManyToMany, ManyToOne } from 'typeorm';
import { BasicREntity } from '../../basicR.type';
import { Farm } from '../../visit/farm.type';

export enum InventoryAreaPastureType{
    GRASS,
    SUGAR_CANE,
    INTENSIVE_PASTURE,
    SEMI_INTENSIVE_PASTURE,
    EXTENSIVE_PASTURE,
    OTHER
}

@Entity()
export class InventoryArea extends BasicREntity {

    @IsNotEmpty()
    @IsDate()
    @Column({ nullable: false })
    date: Date;

    @IsNotEmpty()
    @IsString()
    @Column({ nullable: false })
    name: string;

    @IsNotEmpty()
    @IsNumber()
    @Column()
    size:Number;

    @IsNotEmpty()
    @IsDate()
    @Column()
    lifeSpan:Date;

    @IsNotEmpty()
    @IsNumber()
    @Column()
    cost:Number;

    @IsNotEmpty()
    @IsNumber()
    @Column({type:'int'})
    type:InventoryAreaPastureType

    @IsNotEmpty()
    @ManyToOne(type=>Farm)
    farm:Farm;


}