import { Column, Entity, OneToMany, OneToOne, ManyToOne } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { Installment } from './expense/installment.type';
import { Revenue } from './revenue.type';
import { IsNotEmpty, IsNumber, IsString, IsDate, IsBoolean } from 'class-validator';
import { Farm } from '../visit/farm.type';

export enum ProductionOrderCategory{
    CORN_SILO,
    PASTURE_MAINTENANCE,
    REHIDRATED_CORN
}

@Entity()
export class ProductionOrder extends BasicREntity {

    @IsNotEmpty()
    @IsString()
    @Column()
    name:String;

    @IsNotEmpty()
    @IsNumber()
    @Column({type:'int'})
    type:ProductionOrderCategory;

    @IsNotEmpty()
    @IsDate()
    @Column()
    date:Date;

    @IsNotEmpty()
    @IsBoolean()
    @Column()
    open:Boolean;

    @IsNotEmpty()
    @IsNumber()
    @Column()
    quantity:Number; //KG if rehidrated corn 

    @IsNotEmpty()
    @ManyToOne(type=>Farm)
    farm:Farm

}