import { IsDate, IsNumber, IsNotEmpty, IsOptional } from 'class-validator';
import { Column, Entity, OneToMany, OneToOne, JoinColumn, ManyToOne } from 'typeorm';
import { BasicREntity } from '../../basicR.type';
import { Installment } from '../expense/installment.type';
import { Revenue } from '../revenue.type';

@Entity()
export class Loan extends BasicREntity {
  
  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  date: Date;

  @IsNotEmpty()
  @IsNumber()
  @Column({ nullable: false })
  value: number;

  @IsOptional()
  @OneToMany(type => Installment, installment => installment.loan, { nullable: true })
  installments?: Installment[];

  @IsNotEmpty()
  @ManyToOne(type => Revenue, revenue => revenue.loans, { nullable: false })
  revenue: Revenue;
}