import { IsDate, IsBoolean, IsNumber, IsNotEmpty, IsOptional } from 'class-validator';
import { Column, Entity, ManyToOne, IsNull, OneToOne, JoinColumn, OneToMany } from 'typeorm';
import { Farm } from '../../visit/farm.type';
import { BasicREntity } from '../../basicR.type';
import { Loan } from './loan.type';
import { InventoryMachinery } from '../inventory/inventoryMachinery.type';
import { Animal } from '../../zootechnical/animal.type';

export enum SaleRentRevenueOtherCategory {
  OTHER=1,
  MANURE=2,
  PASTURE=3
}

@Entity()
export class SaleRentRevenue extends BasicREntity {
  
  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  date: Date;

  @IsNotEmpty()
  @ManyToOne(type => Farm, farm => farm.saleRentRevenue, { nullable: false })
  farm: Farm;

  @IsNotEmpty()
  @IsBoolean()
  @Column({ nullable: false })
  sale: boolean; // IF FALSE, IT'S A RENT


  @IsNotEmpty()
  @IsNumber()
  value:Number;

  @IsOptional()
  @ManyToOne(type => InventoryMachinery)
  machinery:InventoryMachinery
  
  @IsOptional()
  @ManyToOne(type => Animal)
  animal:Animal

  @IsOptional()
  @IsNumber()
  otherCategory:SaleRentRevenueOtherCategory
}