import { IsBiggerThan } from '../../validators/isBiggerThan.validator';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToOne, OneToMany , ManyToOne} from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsDate, IsNotEmpty, IsArray, IsOptional, ValidateIf, IsString, Allow } from 'class-validator';
import { DairyCompany } from './dairyCompany.type'
import { Agreement } from './agreement.type';
import BusinessException from '../../exceptions/business.exception';

export enum TypeContract {
  TYPE_1 = 1, // IN76/77
  TYPE_2 = 2 // Programa Leite mais Saudável
}

@Entity()
export class Contract extends BasicREntity {

  @IsNotEmpty()
  @IsString()
  @Column({ nullable: false })
  name: string;

  @IsNotEmpty()
  @ManyToOne(type => DairyCompany, dairyCompany => dairyCompany.contracts, { nullable: false })
  dairyCompany: DairyCompany;

  @IsOptional()
  @IsDate()
  @IsBiggerThan("initialDate", { message: BusinessException.CONTRACT.DATEBIGGER })
  @Column({ nullable: true })
  endDate?: Date;

  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  initialDate: Date;

  @IsOptional()
  @IsString()
  @Column({ nullable: true })
  cancelReason?: string;

  @IsNotEmpty()
  @IsNumber()
  @Column({ nullable: false, type: 'int' })
  type: TypeContract;

  @IsNotEmpty()
  @IsNumber()
  @Column({ nullable: true, default: 0 })
  acquiredMonthlyVisits: number;

  @IsOptional()
  @IsArray()
  @OneToMany(type => Agreement, agreement => agreement.contract, { nullable: true })
  agreements?: Agreement[];
}