import { IsNotEmpty, IsOptional, IsString } from 'class-validator';
import { Column, Entity, JoinColumn, OneToMany, OneToOne } from 'typeorm';
import { Address } from '../app/address.type';
import { BasicREntity } from '../basicR.type';
import { MilkInternalSpending } from '../financial/revenue/milkInnerSpending.type';
import { MilkRevenue } from '../financial/revenue/milkRevenue.type';
import { SaleRentRevenue } from '../financial/revenue/saleRentRevenue.type';
import { InventoryItem } from './../financial/inventory/inventoryItem.type';
import { Animal } from './../zootechnical/animal.type';
import { Agreement } from './agreement.type';
import { FarmConsultant } from './farmConsultant.type';
import { FarmFarmer } from './farmFarmer.type';

@Entity()
export class Farm extends BasicREntity {

  @IsNotEmpty()
  @IsString()
  @Column({ nullable: false })
  name: string;

  @IsNotEmpty()
  @OneToOne(type => Address, { nullable: false, cascade: true })
  @JoinColumn()
  address: Address;

  @IsOptional()
  @OneToMany(type => Agreement, agreement => agreement.farm, { nullable: true })
  agreements?: Agreement[];

  @IsOptional()
  @OneToMany(type => FarmConsultant, farmConsultant => farmConsultant.farm, { nullable: true })
  farmConsultants?: FarmConsultant[];

  @IsNotEmpty()
  @OneToMany(type => FarmFarmer, farmFarmer => farmFarmer.farm, { nullable: false })
  farmFarmers: FarmFarmer[];

  // @IsOptional()
  // @OneToMany(type => Expense, expense => expense.farm, { nullable: true })
  // expenses?: Expense[];

  @IsOptional()
  @OneToMany(type => InventoryItem, inventoryItem => inventoryItem.farm, { nullable: true })
  inventoryItems?: InventoryItem[];

  @IsOptional()
  @OneToMany(type => Animal, animal => animal.farm, { nullable: true })
  animals?: Animal[];

  @IsOptional()
  @OneToMany(type => MilkRevenue, revenue => revenue.farm)
  milkRevenues?: MilkRevenue[];

  @IsOptional()
  @OneToMany(type => SaleRentRevenue, revenue => revenue.farm)
  saleRentRevenue?: SaleRentRevenue[];

  @IsOptional()
  @OneToMany(type => MilkInternalSpending, spending => spending.farm)
  milkInternalSpendings?: MilkInternalSpending[];
}