import { Farm } from './farm.type';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToMany, ManyToOne, OneToOne, ManyToMany } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsNotEmpty, IsOptional, IsArray, IsString, IsBoolean } from 'class-validator';
import { UserConsultant } from './userConsultant.type';
import { Visit } from './visit.type';

export enum ConsultantRole {
    CONSULTANT = 1,
    CONSULTANT_AUX = 2
}

@Entity()
export class FarmConsultant extends BasicREntity {

    @IsNotEmpty()
    @IsNumber()
    @Column({ nullable: false, type: 'int' })
    role: ConsultantRole;

    @IsNotEmpty()
    @ManyToOne(type => Farm, farm => farm.farmConsultants, { nullable: false })
    farm: Farm;

    @IsNotEmpty()
    @ManyToOne(type => UserConsultant, userConsultant => userConsultant.farmConsultants, { nullable: false })
    userConsultant: UserConsultant;

    @IsOptional()
    @IsArray()
    @OneToMany(type => Visit, visit => visit.farmConsultant, { nullable: true })
    visits?: Visit[];
}