import { Address } from '../app/address.type';
import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToMany, ManyToOne, OneToOne, ManyToMany } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { IsNumber, IsNotEmpty, IsOptional, IsArray, IsString, IsBoolean } from 'class-validator';
import { User } from '../app/user.type';
import { Visit } from './visit.type';
import { FarmConsultant } from './farmConsultant.type';

export enum ConsultantEducation {
    VETERINARIAN = 0,
    AGRONOMIST = 1,
    ZOOTECHNIST = 2,
    LIVESTOCK_TECHNICIAN = 3
}

@Entity()
export class UserConsultant extends BasicREntity {

    @IsString()
    @IsNotEmpty()
    @Column({ nullable: false })
    name: string;

    @IsString()
    @IsNotEmpty()
    @Column({ nullable: false })
    emails: string;

    @IsString()
    @IsOptional()
    @Column({ nullable: true })
    linkPhoto?: string;

    @IsString()
    @IsNotEmpty()
    @Column({ nullable: false })
    phones: string;

    @IsString()
    @IsNotEmpty()
    @Column({ nullable: false })
    identification: String;

    @JoinColumn()
    @IsNotEmpty()
    @OneToOne(type => Address, { cascade: true, nullable: false })
    address?: Address;

    @IsNotEmpty()
    @IsNumber()
    @Column({ nullable: false, type: 'int' })
    consultantEducation: ConsultantEducation;

    @IsOptional()
    @ManyToOne(type => UserConsultant, { nullable: true })
    supervisor?: UserConsultant;
    
    @IsOptional()
    @OneToMany(type => FarmConsultant, farmConsultant => farmConsultant.userConsultant, { nullable: false })
    farmConsultants?: FarmConsultant[];
}