import { Entity, Column, JoinColumn, PrimaryGeneratedColumn, OneToMany, OneToOne, ManyToOne } from 'typeorm';
import { BasicREntity } from '../basicR.type';
import { Agreement } from './agreement.type';
import { IsDate, IsNotEmpty, IsNumber, IsOptional, IsBoolean } from 'class-validator';
import { UserConsultant } from './userConsultant.type';
import { FarmConsultant } from './farmConsultant.type';

export enum VisitStatus {
  SCHEDULED = 1,
  DONE = 2,
  PENDING = 3,
  LATE = 4
}

export enum DayTime {
  MORNING = 1,
  EVENING = 2,
  NIGHT = 3
}

@Entity()
export class Visit extends BasicREntity {

  @IsNotEmpty()
  @ManyToOne(type => FarmConsultant, farmConsultant => farmConsultant.visits, { nullable: false })
  farmConsultant: FarmConsultant;
 
  @IsNotEmpty()
  @ManyToOne(type => Agreement, agreement => agreement.visits, { nullable: false })
  agreement: Agreement;

  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  actualDate: Date;

  @IsNotEmpty()
  @IsDate()
  @Column({ nullable: false })
  competence: Date;

  @IsNotEmpty()
  @IsNumber()
  @Column({ nullable: false, type: 'int', default: 1 })
  status: VisitStatus;

  @IsNotEmpty()
  @IsNumber()
  @Column({ nullable: false, type: 'int' })
  dayTime: DayTime;

  // IT'S NECESSARY TO SHOW THE HISTORY OF EDITIONS OF A VISIT.
  // SO, WHEN IT'S EDITED, CREATE A NEW ONE, SET THIS ONE AS EDITED, AND LEAVE THEM AS THE SAME COMPETENCE
  @IsNotEmpty()
  @IsBoolean()
  @Column({ nullable: false})
  isEdited:Boolean;
}